-- Project: ACME test chip - psm control section shift register I/O
-- Create: 9/21/01 
-- File: psm_shift_regs.vhd
-- By: Morris Adams
--
-- Description:  This design acts as a boundry scan I/O for the psm_control.vhd	design
-- The ACME asic is pin limited and this approach allows full testing using 4 pins.
-- 42 signals are shifted serially into this circuit.  Those 42 signals are then 
-- loaded into a 42 bit wide register that drives the inputs of the psm_control.vhd 
-- circuit.  The 28 output bits of the psm_control.vhd circuit are then loaded into
-- a 28 bit wide shift register and serially shifted out.  The psm_control.vhd circuit
-- is instantiated and connected by this design.
--
library IEEE;
use IEEE.std_logic_1164.all;

entity psm_shift_regs is
  port (
-- inputs for serial to parallel stage 

    serial_input : in std_logic; -- test vectors from test bench or IMS tester
    shift_clock : in std_logic; -- Input and Output shift registers clocked on up edge 
    load_reg : in std_logic; -- up edge loads input register. 1 = load output shift reg
--                                                            0 = shift output register	
-- outputs of parallel to serial register 
    serial_output : out std_logic); -- test results sent to test bench or IMS tester
	  
end psm_shift_regs;
--
architecture RTL of psm_shift_regs is
--
-- internal signal definitions
--
signal shift_in_bits : std_logic_vector(41 downto 0); -- the 42 bits of the input shift reg
signal psm_in : std_logic_vector(41 downto 0); -- the 42 inputs to the psm control circuit
signal shift_out_bits : std_logic_vector(27 downto 0); -- the 28 bits of the output shift reg
signal	psm_out : std_logic_vector(27 downto 0); -- the 28 outputs of the psm control circuit 

-- component declare
	component psm_control
		port (
		-- inputs to digital section
    temperin : in std_logic; -- 
    dtsd : in std_logic; -- 0 = shutdown
    sysreset : in std_logic; -- 1 = reset
    vpwm : in std_logic; -- 0 = shutdown        
    ph1bypas : in std_logic; -- 
    ph2bypas : in std_logic; -- 0 = ignore bit
    vrefhi : in std_logic; -- 
    vreflo : in std_logic; -- 0 = failure
    disa : in std_logic; -- 
	disb : in std_logic; -- 
	onoffdis : in std_logic; -- 
    vpfi : in std_logic; -- 	
	ptinput : in std_logic; -- 
	pficml4 : in std_logic; -- 
	pficml3 : in std_logic; -- 
	ntimeout : in std_logic; -- 0 = no pwmclk
	pwmbypas : in std_logic; -- 1 = selects pwm clock
	mrsel : in std_logic; -- 1 = selects shutdown
	v01rssd : in std_logic; -- 
	v01sdin : in std_logic; -- 
	v01ovin : in std_logic; -- 
	v01uvin : in std_logic; -- 
	v02sdin : in std_logic; -- 
	v02ovin : in std_logic; -- 
	v02uvin : in std_logic; -- 
	v03sdin : in std_logic; -- 
	v03ovin : in std_logic; -- 
	v03uvin : in std_logic; -- 
	ps1bypas : in std_logic; -- 0 = disable supply monitor
	ps2bypas : in std_logic; -- 
	ps3bypas : in std_logic; -- 
	vinovin : in std_logic; -- 
	vinuvin : in std_logic; -- 
	catis_sd : in std_logic; -- 
	iout1uc : in std_logic; -- 
	iout1oc : in std_logic; -- 
	iout2oc : in std_logic; -- 
	iout3oc : in std_logic; -- 
	slftst : in std_logic; -- 
	fwnoen : in std_logic; --
	fwoen : in std_logic; --
	fwlatch_t : in std_logic; -- latch control signal for faltlatch block. "0" = transparent
-- outputs of digital section	
    otout : out std_logic; -- also called ot13ocml
	ovrtmpout_c2 : out std_logic; -- output from faltlatch
    otsd_tp : out std_logic; -- 
    vpwm_tp : out std_logic; -- 
    nonout : out std_logic; -- 
	ponout : out std_logic; --
	pwmon : out std_logic; -- 1 = pwm on
	pupass_c2 : out std_logic; -- output from faltlatch. 0 = failure
	cmdnout : out std_logic; --
	pficml2 : out std_logic; --
	pficml1 : out std_logic; --
	vosd_c2 : out std_logic; -- output from faltlatch
	mrfire : out std_logic; --
	vrsd_tp : out std_logic; --
	v01ov_c2 : out std_logic; --	output from faltlatch
	v01uv_c2 : out std_logic; --	output from faltlatch
	v02ov_c2 : out std_logic; --	output from faltlatch
	v02uv_c2 : out std_logic; --	output from faltlatch
	v03ov_c2 : out std_logic; --	output from faltlatch
	v03uv_c2 : out std_logic; --	output from faltlatch
	vinov_c2 : out std_logic; --	output from faltlatch
	vinuv_c2 : out std_logic; --	output from faltlatch
	catis : out std_logic; --
	io1uc_c2 : out std_logic; --	output from faltlatch
	io1oc_c2 : out std_logic; --	output from faltlatch
	io2oc_c2 : out std_logic; --	output from faltlatch
	io3oc_c2 : out std_logic; --	output from faltlatch
	tsout : out std_logic --
	   );
end component;
--
begin -- architecture body
--
-- component instantiation
	x1 : psm_control
	port map (
	-- connect input signals of psm_control to the psm load_register
    temperin => psm_in(0), 
    dtsd => psm_in(1), 
    sysreset => psm_in(2),
    vpwm => psm_in(3),        
    ph1bypas => psm_in(4), 
    ph2bypas => psm_in(5),
    vrefhi => psm_in(6), 
    vreflo => psm_in(7),
    disa => psm_in(8), 
	disb => psm_in(9), 
	onoffdis => psm_in(10), 
    vpfi => psm_in(11),	
	ptinput => psm_in(12),
	pficml4 => psm_in(13),
	pficml3 => psm_in(14),
	ntimeout => psm_in(15),
	pwmbypas => psm_in(16),
	mrsel => psm_in(17),
	v01rssd => psm_in(18),
	v01sdin => psm_in(19),
	v01ovin => psm_in(20),
	v01uvin => psm_in(21),
	v02sdin => psm_in(22),
	v02ovin => psm_in(23),
	v02uvin => psm_in(24),
	v03sdin => psm_in(25),
	v03ovin => psm_in(26),
	v03uvin => psm_in(27),
	ps1bypas => psm_in(28),
	ps2bypas => psm_in(29),
	ps3bypas => psm_in(30),
	vinovin => psm_in(31),
	vinuvin => psm_in(32),
	catis_sd => psm_in(33),
	iout1uc => psm_in(34),
	iout1oc => psm_in(35), 
	iout2oc => psm_in(36),
	iout3oc => psm_in(37), 
	slftst => psm_in(38),
	fwnoen => psm_in(39),
	fwoen => psm_in(40),
	fwlatch_t => psm_in(41),
-- connect outputs of psm to the output shift register	
    otout => psm_out(0),
	ovrtmpout_c2 => psm_out(1),
    otsd_tp => psm_out(2),
    vpwm_tp => psm_out(3),
    nonout => psm_out(4),
	ponout => psm_out(5),
	pwmon => psm_out(6),
	pupass_c2 => psm_out(7),
	cmdnout => psm_out(8),
	pficml2 => psm_out(9),
	pficml1 => psm_out(10),
	vosd_c2 => psm_out(11),
	mrfire => psm_out(12),
	vrsd_tp => psm_out(13),
	v01ov_c2 => psm_out(14),
	v01uv_c2 => psm_out(15),
	v02ov_c2 => psm_out(16),
	v02uv_c2 => psm_out(17),
	v03ov_c2 => psm_out(18),
	v03uv_c2 => psm_out(19),
	vinov_c2 => psm_out(20),
	vinuv_c2 => psm_out(21),
	catis => psm_out(22),
	io1uc_c2 => psm_out(23),
	io1oc_c2 => psm_out(24),
	io2oc_c2 => psm_out(25),
	io3oc_c2 => psm_out(26),
	tsout => psm_out(27));
--
---------------shift in------------------------
-- 
input_shiftreg : process (shift_clock) begin
	if rising_edge(shift_clock) then  -- bit 0 shifted first, bit 41 last
		shift_in_bits(40 downto 0) <= shift_in_bits(41 downto 1);
		shift_in_bits(41) <= serial_input;
	end if;
end process;
--
--------------input load register---------------------
--
input_register : process (load_reg) begin
	if rising_edge(load_reg) then
		psm_in <= shift_in_bits; -- all 42 bits are clocked into the register
	end if;
end process;
--
--------------shift out------------------------
--
output_shiftreg : process (shift_clock, load_reg) begin
	if rising_edge(shift_clock) then
		if (load_reg = '1') then -- parallel load of output shift register
			shift_out_bits <= psm_out; -- all 28 output bits are loaded into shift reg 
		else -- shift the register by 1 bit.  bit 0 is first out, bit 27 is last
			shift_out_bits(26 downto 0) <= shift_out_bits(27 downto 1);
			shift_out_bits(27) <= '1'; -- force ones into the shift register msb
		end if;	
	end if;
end process;
serial_output <= shift_out_bits(0); -- shift register lsb is the output

--
end RTL;











































